import { message } from 'antd';
import * as XLSX from 'xlsx';

function s2ab(s) {
    var buf = new ArrayBuffer(s.length);
    var view = new Uint8Array(buf);
    for (var i = 0; i != s.length; ++i) view[i] = s.charCodeAt(i) & 0xFF;
    return buf;
}

export default function exportDataToXlsx(data: {},fileName: string) {
    let workbook = XLSX.utils.book_new();
    if (data) {
        Object.keys(data).forEach(sheetName => {
            //为工作簿中添加工作表
            let workSheet: XLSX.WorkSheet;
            if (data[sheetName].length > 0) {
                if (data[sheetName][0] instanceof Array) {
                    workSheet = XLSX.utils.aoa_to_sheet(data[sheetName]);
                } else if (data[sheetName][0] instanceof Object) {
                    workSheet = XLSX.utils.json_to_sheet(data[sheetName]);
                }
            }
            XLSX.utils.book_append_sheet(workbook, workSheet, sheetName);
        });
        //将工作簿转化为二进制文件blob类型
        let wopts = {
            bookType: 'xlsx', // 要生成的文件类型
            bookSST: false,   // 是否生成Shared String Table，官方解释是，如果开启生成速度会下降，但在低版本IOS设备上有更好的兼容性
            type: 'binary'    // 二进制文件
        };
        let wbout = XLSX.write(workbook, wopts as any);
        let blob = new Blob([s2ab(wbout)], { type: "application/octet-stream" });

        //下载blob的过程
        const link = document.createElement('a');
        link.setAttribute('href', window.URL.createObjectURL(blob));
        link.setAttribute('download', `${fileName}.xlsx`);
        link.style.visibility = 'hidden';
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
    } else {
        message.warning("导出数据未指定")
    }
}